@@ -7,24 +7,21 @@ These pipelines are developed by the Poldrack lab at Stanford University
 the Center for Reproducible Neuroscience (http://reproducibility.stanford.edu/),
 as well as for open-source software distribution.
 """
-from __future__ import absolute_import, division, print_function
-import datetime
-from os import path as op
-import runpy
+from datetime import datetime
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
 
-nipype_info = runpy.run_path(op.join(op.abspath(op.dirname(__file__)),
-                                     'nipype', 'info.py'))
-
-__version__ = '0.3.10'
 __packagename__ = 'niworkflows'
 __author__ = 'The CRN developers'
 __copyright__ = 'Copyright {}, Center for Reproducible Neuroscience, Stanford University'.format(
-    datetime.datetime.now().year)
-__credits__ = ['Oscar Esteban', 'Ross Blair', 'Shoshana L. Berleant', 'Chris Gorgolewski',
+    datetime.now().year)
+__credits__ = ['Oscar Esteban', 'Ross Blair', 'Shoshana L. Berleant',
+               'Christopher J. Markiewicz', 'Chris Gorgolewski',
                'Russell A. Poldrack']
 __license__ = '3-clause BSD'
 __maintainer__ = 'Oscar Esteban'
-__email__ = 'crn.poldracklab@gmail.com'
+__email__ = 'code@oscaresteban.es'
 __status__ = 'Prototype'
 
 __description__ = """\
@@ -39,11 +36,11 @@ acquisition protocols and that requires minimal user input. \
 This open-source neuroimaging data processing tool is being developed as a part of \
 the MRI image analysis and reproducibility platform offered by the CRN.\
 """
+__url__ = 'https://github.com/poldracklab/{}'.format(__packagename__)
 
 DOWNLOAD_URL = (
     'https://pypi.python.org/packages/source/{name[0]}/{name}/{name}-{ver}.tar.gz'.format(
         name=__packagename__, ver=__version__))
-URL = 'https://github.com/poldracklab/{}'.format(__packagename__)
 CLASSIFIERS = [
     'Development Status :: 3 - Alpha',
     'Intended Audience :: Science/Research',
@@ -51,29 +48,42 @@ CLASSIFIERS = [
     'License :: OSI Approved :: BSD License',
     'Programming Language :: Python :: 3.5',
     'Programming Language :: Python :: 3.6',
+    'Programming Language :: Python :: 3.7',
 ]
 
-REQUIRES = nipype_info['REQUIRES'] + [
-    'nilearn>=0.2.6',
-    'sklearn',
-    'pandas',
-    'matplotlib',
+REQUIRES = [
+    'grabbit==0.2.3',
     'jinja2',
-    'svgutils',
+    'matplotlib>=2.2.0',
+    'nilearn>=0.2.6',
+    'nipype>=1.1.6',
+    'packaging',
+    'pandas',
+    'pybids==0.6.5',
+    'scikit-image',
+    'scipy',
     'seaborn',
+    'svgutils',
 ]
 
 SETUP_REQUIRES = []
 REQUIRES += SETUP_REQUIRES
 
 LINKS_REQUIRES = []
-TESTS_REQUIRES = ['mock', 'codecov', 'pytest-xdist', 'pytest']
+TESTS_REQUIRES = [
+    'pytest',
+    'pytest-xdist',
+]
 
 EXTRA_REQUIRES = {
-    'doc': ['sphinx'],
+    'doc': [
+        'sphinx>=1.5.3',
+        'pydotplus',
+        'pydot>=1.2.3',
+    ],
+    'duecredit': ['duecredit'],
     'tests': TESTS_REQUIRES,
-    'duecredit': ['duecredit']
 }
 
 # Enable a handle to install all extra dependencies at once
-EXTRA_REQUIRES['all'] = [val for _, val in list(EXTRA_REQUIRES.items())]
+EXTRA_REQUIRES['all'] = list(EXTRA_REQUIRES.values())
