@@ -23,7 +23,7 @@ from svgutils.transform import SVGFigure
 from seaborn import color_palette
 
 from .. import NIWORKFLOWS_LOG
-from ..nipype.utils import filemanip
+from nipype.utils import filemanip
 
 try:
     from shutil import which
@@ -283,28 +283,34 @@ def plot_segs(image_nii, seg_niis, out_file, bbox_nii=None, masked=False,
 
 def _plot_anat_with_contours(image, segs=None, compress='auto',
                              **plot_params):
-    assert segs is not None
-
+    nsegs = len(segs or [])
     plot_params = plot_params or {}
-    colors = plot_params.pop('colors', []) or []  # colors should not be None
-    nsegs = len(segs)
+    # plot_params' values can be None, however they MUST NOT
+    # be None for colors and levels from this point on.
+    colors = plot_params.pop('colors', None) or []
+    levels = plot_params.pop('levels', None) or []
     missing = nsegs - len(colors)
     if missing > 0:  # missing may be negative
         colors = colors + color_palette("husl", missing)
 
+    colors = [[c] if not isinstance(c, list) else c
+              for c in colors]
+
+    if not levels:
+        levels = [[0.5]] * nsegs
+
     # anatomical
     display = plot_anat(image, **plot_params)
 
     # remove plot_anat -specific parameters
     plot_params.pop('display_mode')
     plot_params.pop('cut_coords')
-    plot_params['levels'] = np.atleast_1d(
-        plot_params.get('levels', 0.5)).tolist()
 
     plot_params['linewidths'] = 0.5
     for i in reversed(range(nsegs)):
-        plot_params['colors'] = [colors[i]]
-        display.add_contours(segs[i], **plot_params)
+        plot_params['colors'] = colors[i]
+        display.add_contours(segs[i], levels=levels[i],
+                             **plot_params)
 
     svg = extract_svg(display, compress=compress)
     display.close()
@@ -538,9 +544,10 @@ def plot_melodic_components(melodic_dir, in_file, tr=None,
                   width_ratios=[1, 1, 1, 4, 0.001, 1, 1, 1, 4, ],
                   height_ratios=[1.1, 1] * n_rows)
 
+    noise_components = None
     if noise_components_file:
-        with open(noise_components_file) as cf:
-            noise_components = [int(c) for c in cf.read().split(",")]
+        noise_components = np.loadtxt(noise_components_file,
+                                      dtype=int, delimiter=',', ndmin=1)
 
     for i, img in enumerate(
             iter_img(os.path.join(melodic_dir, "melodic_IC.nii.gz"))):
@@ -549,15 +556,15 @@ def plot_melodic_components(melodic_dir, in_file, tr=None,
         row = int(i / 2)
         l_row = row * 2
 
-        if noise_components_file:
-            if (i + 1) in noise_components:
-                color_title = color_time = color_power = 'r'
-            else:
-                color_title = color_time = color_power = 'g'
-        else:
-            color_title = 'k'
-            color_time = current_palette[0]
-            color_power = current_palette[1]
+        # Set default colors
+        color_title = 'k'
+        color_time = current_palette[0]
+        color_power = current_palette[1]
+
+        if noise_components is not None and noise_components.size > 0:
+            # If a noise components list is provided, assign red/green
+            color_title = color_time = color_power = (
+                'r' if (i + 1) in noise_components else 'g')
 
         data = img.get_data()
         for j in range(3):
